@@ -1,6 +1,6 @@
 /* Low level support for x86 (i386 and x86-64).
 
-   Copyright (C) 2009-2017 Free Software Foundation, Inc.
+   Copyright (C) 2009-2019 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -17,8 +17,12 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
+#ifndef GDBSERVER_X86_LOW_H
+#define GDBSERVER_X86_LOW_H
 
 #include "nat/x86-dregs.h"
 
 /* Initialize STATE.  */
 extern void x86_low_init_dregs (struct x86_debug_reg_state *state);
+
+#endif /* GDBSERVER_X86_LOW_H */
